@@ -47,8 +47,8 @@ class CGSmartImage extends CGExtensions
   function LazyLoadFrontend() { return FALSE; }
   function GetName() { return get_class($this); }
   function GetFriendlyName() { return $this->Lang('friendlyname');  }
-  function GetVersion() { return '1.10.6'; }
-  function MinimumCMSVersion() { return '1.11.3'; }
+  function GetVersion() { return '1.10.8'; }
+  function MinimumCMSVersion() { return '1.11.4'; }
   function GetDependencies() { return array('CGExtensions'=>'1.32');   }
   function GetAuthor() { return 'calguy1000'; }
   function GetAuthorEmail() { return 'calguy1000@gmail.com'; }
@@ -59,6 +59,11 @@ class CGSmartImage extends CGExtensions
   function VisibleToAdminUser() { return $this->CheckPermission('Modify Site Preferences'); }
   function AllowAutoInstall() { return FALSE; }
   function AllowAutoUpgrade() { return FALSE; }
+  function GetHelp() { return file_get_contents(__DIR__.'/help.inc'); }
+  function GetAdminDescription() { return $this->Lang('moddescription'); }
+  function GetChangeLog() { return @file_get_contents(__DIR__.'/changelog.html.inc'); }
+  function InstallPostMessage() { return $this->Lang('postinstall'); }
+  function UninstallPostMessage() { return $this->Lang('postuninstall'); }
   
   public function InitializeFrontend()
   {
@@ -150,31 +155,6 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('filter_watermark','',$this->Lang('param_filter_watermark'));
   }
 
-  function GetHelp() 
-  { 
-    return file_get_contents(__DIR__.'/help.inc');
-  }
-
-  function GetAdminDescription()
-  {
-    return $this->Lang('moddescription');
-  }
-  
-  function GetChangeLog()
-  {
-    return @file_get_contents(__DIR__.'/changelog.html.inc');
-  }
-
-  function InstallPostMessage()
-  {
-    return $this->Lang('postinstall');
-  }
-
-  function UninstallPostMessage()
-  {
-    return $this->Lang('postuninstall');
-  }
-
   protected function can_smart_embed($src)
   {
     global $CMS_ADMIN_PAGE;
