@@ -50,11 +50,13 @@ $tmp['bc'] = $this->Lang('prompt_loc_bottomcenter');
 $tmp['br'] = $this->Lang('prompt_loc_bottomright');
 $smarty->assign('croptofit_locs',$tmp);
 $smarty->assign('cache_age',$this->GetPreference('cache_age'));
+$smarty->assign('cache_path',$this->GetPreference('cache_path', cms_join_path('uploads', '_'.$this->GetName())));
 $smarty->assign('image_url_prefix',$this->GetPreference('image_url_prefix'));
 $smarty->assign('croptofit_default_loc',$this->GetPreference('croptofit_default_loc','c'));
 $smarty->assign('image_url_hascachedir',$this->GetPreference('image_url_hascachedir'));
 $smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_general_tab'));
 $smarty->assign('formend',$this->CreateFormEnd());
+$smarty->assign('silent',$this->GetPreference('silent',0));
 echo $this->ProcessTemplate('admin_general_tab.tpl');
 
 #
