@@ -9,6 +9,7 @@ $lang['ask_clear_image_cache'] = 'Are you sure you want to remove ALL files from
 # C
 $lang['clear_all'] = 'Clear All Files';
 $lang['clear_now'] = 'Clear Now';
+$lang['cache_path'] = 'Cache Path';
 
 # D
 $lang['delete'] = 'Delete';
@@ -42,14 +43,16 @@ $lang['info_aliases'] = 'Aliaes can be used via the alias1 through alias5 option
 $lang['info_croptofit_default_loc'] = 'Specify the default location from which to &quot;crop to fit&quot; this will effect all crop to fit operations unless the location parameter on the filter_croptofit attribute overrides it.  Default location is &quot;center&quot;';
 $lang['info_responsive'] = 'If enabled, CGSmartImage will attempt to detect the maximum resolution of the requesting device and automatically rescale the image so that under no circumstances can the output image be too large for the display.  This assists in performance when developing mobile websites.';
 $lang['info_responsive_breakpoints'] = '<strong>Experimental:</strong> If specified, and a mobile device is detected the breakpoints will be used to determine the maximum largest edge for the resulting image.  Specify a list of comma separated increasing integers <em>(i.e: 200,400,600,800)</em>. The device capabilties will be used to find the closest matching breakpoint value.  The image will be resized so that its largest edge is at that value without upscaling.  Aspect ratio will be maintained.';
-$lang['image_url_hascachedir'] = 'Does the URL above acount for the cache directory (_CGSmartImage)';
+$lang['image_url_hascachedir'] = 'Does the URL above acount for the cache path? ie. (uploads/_CGSmartImage)';
 $lang['image_url_prefix'] = 'Image Url Prefix';
 $lang['info_cache_age'] = 'Specify the maximum age of a file (in days) before it will be removed and forced to regenerate.  This is useful if you have changed some of the parameters used when generating images, or to control the amount of disk space used.  Entering 0 will disable automatic file deletion';
+$lang['info_cache_path'] = 'Cache path for cache images to be stored. Cache path is relative to config reference "root_path".';
 $lang['info_embed_mode'] = 'This selection determines how the {smartimg} tag will generate output.  If &quot;none&quot; is selected no image embedding will be performed.  If &quot;smart&quot; is selected then the system will decide based on the image size, type, and the browser that is requesting the image.  Other options include always embedding based on the image size, or the image type.';
 $lang['info_embed_sizelimit'] = 'If the embedding option is determied by the image size, specify the maximum size (in kilobytes) for images to be embedded (32 is recommended).';
 $lang['info_embed_types'] = 'If the embedding option is determined by the image type, specify the extensions of the files that should be embedded here separated by commas.  This option is not case sensitive';
 $lang['info_image_url_hascachedir'] = 'If your CDN is pointing directly at the image cache directory then you may want to turn this option on.';
 $lang['info_image_url_prefix'] = 'Specify the URL to prefix to all generated images.  By default this is the uploads URL, however if you have your own CDN (or multiple domains pointing at the same directory) You may want to specify a different name here';
+$lang['info_suppress_errors'] = 'Specify a default value for the &quot;silent&quot; parameter';
 
 # M
 $lang['max_cache_age'] = 'Maximum Cache File Age (days)';
@@ -82,6 +85,7 @@ $lang['param_filter_grayscale'] = '(anything) Convert the image to grayscale';
 $lang['param_filter_meanremoval'] = '(anything) Attempt to achieve a &quot;sketchy&quot; effect';
 $lang['param_filter_negate'] = '(anything) Negate the image';
 $lang['param_filter_pixelate'] = '(size[,advanced]) Pixelate the image, specify an integer size and an optional boolean (default is false) to enable advanced pixelation';
+$lang['param_filter_reflect'] = '([reflection_height[,reflection_opacity[,divider_height]]]), Creates reflection of image, currently working only with jpg,jpeg images against white background.';
 $lang['param_filter_resize'] = 'type,number[,number[,upscale]] - Perform a resize of the source image.  By default, the resize filter allows upscaling.  Possible values are:
 <ul>
   <li>p,number - Perform a simple rescale to a certain percentage.  i.e:  resize=p,50 to resize to 50% of the original size.</li>
@@ -154,5 +158,6 @@ $lang['responsive_breakpoints'] = 'Specify responsive image maximum edge breakpo
 # S
 $lang['smart'] = 'Smart';
 $lang['submit'] = 'Submit';
+$lang['suppress_errors'] = 'Suppress Errors';
 
 ?>
