@@ -253,7 +253,7 @@ class CGImageBase implements ArrayAccess
 	$res = imagejpeg($this['rsrc'],$filename,$quality);
 	break;
       case 'image/png':
-	$quality = (int)($quality/10.0);
+	$quality = ceil((100.0 - (float)$quality)/100.0*10.0);
 	$res = imagepng($this['rsrc'],$filename,$quality);
 	break;
       case 'image/gif':
