@@ -43,27 +43,21 @@ class cgsi_utils
   private static function _get_alias_options($name)
   {
     static $aliases;
-    if( !$aliases )
-      {
-	$mod = cms_utils::get_module('CGSmartImage');
-	$tmp = $mod->GetPreference('aliases');
-	if( !$tmp ) 
-	  $aliases = 'FALSE';
-	else
-	  $aliases = unserialize($tmp);
-      }
-    if( is_array($aliases) )
-      {
-	$keys = array_keys($aliases);
-	for( $i = 0; $i < count($keys); $i++ )
-	  {
-	    $key = $keys[$i];
-	    if( $aliases[$key]['name'] == $name )
-	      {
-		return $aliases[$key]['options'];
-	      }
-	  }
+    if( !$aliases ) {
+      $mod = cms_utils::get_module('CGSmartImage');
+      $tmp = $mod->GetPreference('aliases');
+      if( !$tmp ) 
+	$aliases = 'FALSE';
+      else
+	$aliases = unserialize($tmp);
+    }
+    if( is_array($aliases) ) {
+      $keys = array_keys($aliases);
+      for( $i = 0; $i < count($keys); $i++ ) {
+	$key = $keys[$i];
+	if( $aliases[$key]['name'] == $name ) return $aliases[$key]['options'];
       }
+    }
   }
 
 
@@ -73,58 +67,48 @@ class cgsi_utils
     $col = '';
     $safe = '';
     $prev_char = '';
-    for( $i = 0; $i < strlen($str); $i++ )
-      {
-	switch( $str[$i] )
-	  {
-	  case ' ':
-	    if( !$safe )
-	      {
-		if( strpos($col,'=') !== FALSE )
-		  {
-		    list($k,$v) = explode('=',$col,2);
-		    $result[$k] = $v;
-		  }
-		$col = '';
-	      }
-	    else
-	      {
-		$col .= $str[$i];
-	      }
-	    break;
-
-	  case "'":
-	  case '"':
-	    if( $prev_char != '\\' )
-	      {
-		if( $str[$i] == $safe )
-		  {
-		    $safe = null;
-		  }
-		else
-		  {
-		    $safe = $str[$i];
-		  }
-	      }
-	    break;
-
-	  default:
-	    $col .= $str[$i];
-	    break;
-	  }
-
-	$prev_char = $str[$i];
-      }
-
-    if( strlen($col) != 0 )
-      {
-	if( strpos($col,'=') !== FALSE )
-	  {
+    for( $i = 0; $i < strlen($str); $i++ ) {
+      switch( $str[$i] ) {
+      case ' ':
+	if( !$safe ) {
+	  if( strpos($col,'=') !== FALSE ) {
 	    list($k,$v) = explode('=',$col,2);
 	    $result[$k] = $v;
 	  }
+	  $col = '';
+	}
+	else {
+	  $col .= $str[$i];
+	}
+	break;
+
+      case "'":
+      case '"':
+	if( $prev_char != '\\' ) {
+	  if( $str[$i] == $safe ) {
+	    $safe = null;
+	  }
+	  else {
+	    $safe = $str[$i];
+	  }
+	}
+	break;
+
+      default:
+	$col .= $str[$i];
+	break;
       }
 
+      $prev_char = $str[$i];
+    }
+
+    if( strlen($col) != 0 ) {
+      if( strpos($col,'=') !== FALSE ) {
+	list($k,$v) = explode('=',$col,2);
+	$result[$k] = $v;
+      }
+    }
+
     return $result;
   }
 
@@ -132,10 +116,9 @@ class cgsi_utils
   private static function _is_stylesheet()
   {
     $tmp = debug_backtrace();
-    foreach( $tmp as $elem )
-      {
-	if( isset($elem['function']) && $elem['function'] == 'smarty_cms_function_cms_stylesheet' ) return TRUE;
-      }
+    foreach( $tmp as $elem ) {
+      if( isset($elem['function']) && $elem['function'] == 'smarty_cms_function_cms_stylesheet' ) return TRUE;
+    }
     return FALSE;
   }
 
@@ -145,50 +128,42 @@ class cgsi_utils
     $str = trim($str);
     $res = array(0,0,0);
 
-    if( startswith($str,'#') && strlen($str) == 7 )
-      {
-	$res[0] = hexdec(substr($str,1,2));
-	$res[1] = hexdec(substr($str,3,2));
-	$res[2] = hexdec(substr($str,5,2));
-	return $res;
-      }
-    
+    if( startswith($str,'#') && strlen($str) == 7 ) {
+      $res[0] = hexdec(substr($str,1,2));
+      $res[1] = hexdec(substr($str,3,2));
+      $res[2] = hexdec(substr($str,5,2));
+      return $res;
+    }
+
     $tmp = explode(':',$str,3);
-    if( is_array($tmp) && count($tmp) == 3 && is_numeric($tmp[0]) && is_numeric($tmp[1]) && is_numeric($tmp[1]) )
-      {
-	$res[0] = (int)$tmp[0];
-	$res[1] = (int)$tmp[1];
-	$res[2] = (int)$tmp[2];
-	return $res;
-      }
-    
+    if( is_array($tmp) && count($tmp) == 3 && is_numeric($tmp[0]) && is_numeric($tmp[1]) && is_numeric($tmp[1]) ) {
+      $res[0] = (int)$tmp[0];
+      $res[1] = (int)$tmp[1];
+      $res[2] = (int)$tmp[2];
+      return $res;
+    }
+
     // assume it's a color name.
     static $_colors;
-    if( !is_array($_colors) )
-      {
-	$fn = dirname(__FILE__).'/colors.dat';
-	$data = file($fn);
-	if( count($data) )
-	  {
-	    $_colors = array();
-	    for( $i = 0; $i < count($data); $i++ )
-	      {
-		list($rgb,$name) = explode('-',$data[$i],2);
-		if( !startswith($rgb,'#') || strlen($rgb) != 7 || $name == '' ) continue;
+    if( !is_array($_colors) ) {
+      $fn = dirname(__FILE__).'/colors.dat';
+      $data = file($fn);
+      if( count($data) ) {
+	$_colors = array();
+	for( $i = 0; $i < count($data); $i++ ) {
+	  list($rgb,$name) = explode('-',$data[$i],2);
+	  if( !startswith($rgb,'#') || strlen($rgb) != 7 || $name == '' ) continue;
 
-		$tmp = array();
-		$tmp[0] = hexdec(substr($rgb,1,2));
-		$tmp[1] = hexdec(substr($rgb,3,2));
-		$tmp[2] = hexdec(substr($rgb,5,2));
+	  $tmp = array();
+	  $tmp[0] = hexdec(substr($rgb,1,2));
+	  $tmp[1] = hexdec(substr($rgb,3,2));
+	  $tmp[2] = hexdec(substr($rgb,5,2));
 
-		$_colors[strtolower(trim($name))] = $tmp;
-	      }
-	  }
-      }
-    if( is_array($_colors) && isset($_colors[$str]) )
-      {
-	$res = $_colors[$str];
+	  $_colors[strtolower(trim($name))] = $tmp;
+	}
       }
+    }
+    if( is_array($_colors) && isset($_colors[$str]) ) $res = $_colors[$str];
     return $res;
   }
 
@@ -350,6 +325,12 @@ class cgsi_utils
 	$srcfile = $tmp;
       }
     }
+    if( !$outp['error'] && !$srcfile && isset($config['ssl_url']) && startswith($opp['src'],$config['ssl_url']) ) {
+      $tmp = str_replace($config['ssl_url'],$config['root_path'],$opp['src']);
+      if( file_exists($tmp) ) {
+	$srcfile = $tmp;
+      }
+    }
     if( !$outp['error'] && !$srcfile && startswith($opp['src'],'/') ) {
       $tmp = cms_join_path($config['root_path'],$opp['src']);
       $rp1 = realpath($config['root_path']);
@@ -359,16 +340,19 @@ class cgsi_utils
       }
     }
     if( !$outp['error'] && !$srcfile ) {
+      // check relative path wrt the uploads dir.
       $tmp = cms_join_path($config['uploads_path'],$opp['src']);
-      $rp1 = realpath($config['root_path']);
+      $rp1 = realpath($config['uploads_path']);
       $rp2 = realpath($tmp);
       if( startswith($rp2,$rp1) && file_exists($tmp) ) {
 	$srcfile = $tmp;
       }
     }
-    if( !$outp['error'] && !$srcfile && isset($config['ssl_url']) && startswith($opp['src'],$config['ssl_url']) ) {
-      $tmp = str_replace($config['ssl_url'],$config['root_path'],$opp['src']);
-      if( file_exists($tmp) ) {
+    if( !$outp['error'] && !$srcfile ) {
+      $tmp = cms_join_path($config['root_path'],$opp['src']);
+      $rp1 = realpath($config['root_path']);
+      $rp2 = realpath($tmp);
+      if( startswith($rp2,$rp1) && file_exists($tmp) ) {
 	$srcfile = $tmp;
       }
     }
@@ -462,7 +446,7 @@ class cgsi_utils
 	}
       }
     }
-    
+
     // now do some intelligence, and see if the width, and height arguments passed in
     // match the image size... if not, add a filter.
     if( !$outp['error'] && $srcfile && ($outp['width'] > 0 || $outp['height'] > 0) && $opp['noautoscale'] == 0 ) {
@@ -653,7 +637,8 @@ class cgsi_utils
 	}
       }
       catch( Exception $e ) {
-	$outp['error'] = $e->getMessage();
+	audit('','CGSmartImage','Error encountered on '.$opp['src'].': '.$e->GetMessage());
+	$outp['error'] = $e->GetMessage();
       }
     } // if
 
